package com.qmth.pdf.tools;

import com.qmth.pdf.tools.config.PdfConfig;
import com.qmth.pdf.tools.service.StudentPaperService;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.CommandLineRunner;
import org.springframework.boot.SpringApplication;
import org.springframework.boot.autoconfigure.SpringBootApplication;
import org.springframework.boot.context.properties.EnableConfigurationProperties;
import org.springframework.util.StringUtils;
import springfox.documentation.swagger2.annotations.EnableSwagger2;

import java.util.Arrays;

@SpringBootApplication
@EnableConfigurationProperties
@EnableSwagger2
public class PdfToolsApplication implements CommandLineRunner {

    private static final Logger logger = LoggerFactory.getLogger(PdfToolsApplication.class);

    @Autowired
    private StudentPaperService studentPaperService;

    @Autowired
    private PdfConfig pdfConfig;

    public static void main(String[] args) {
        SpringApplication.run(PdfToolsApplication.class, args);
    }

    @Override
    public void run(String... args) throws Exception {
        // 生成考生的试卷json文件
        String subjectCode = pdfConfig.getSubjectCode();
        String examId = pdfConfig.getExamId();

        if (examId == null || StringUtils.isEmpty(examId)) {
            logger.warn("examId不能为空，请在application.properties中配置");
            return;
        }
        if(StringUtils.isEmpty(subjectCode)) {
            subjectCode = null;
        }

        String[] examIdArr = splitAndCleanExamIds(examId);
        // 多个examId时，subjectCode设置为null
        if (examIdArr.length > 1) {
            subjectCode = null;
        }
        for (String id : examIdArr) {
            try {
                long examIdLong = Long.parseLong(id);
                studentPaperService.outputStudentPaperJson(examIdLong, subjectCode);
            } catch (NumberFormatException e) {
                logger.warn("examId:{} 格式错误，只能是数字，请不要包含其他字符", id, e);
            } catch (Exception e) {
                logger.error("处理examId:{}时发生未知错误", id, e);
            }
        }
    }

    private String[] splitAndCleanExamIds(String examId) {
        return Arrays.stream(examId.split(","))
                .map(String::trim) // 去除前后空格
                .filter(id -> !StringUtils.isEmpty(id)) // 过滤掉空字符串
                .toArray(String[]::new);
    }
}