package com.qmth.pdf.tools.config;

import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import org.springframework.scheduling.concurrent.ThreadPoolTaskExecutor;

import java.util.concurrent.ThreadPoolExecutor;

@Configuration
public class ThreadPoolConfig {

    @Bean
    public ThreadPoolTaskExecutor taskExecutor() {
        ThreadPoolTaskExecutor executor = new ThreadPoolTaskExecutor();

        // 获取可用处理器核心数
        int availableProcessors = Runtime.getRuntime().availableProcessors();

        // 设置核心线程数为核心数
        executor.setCorePoolSize(availableProcessors);

        // 设置最大线程数为核心数的两倍
        executor.setMaxPoolSize(availableProcessors * 2);

        // 设置队列大小为核心数的四倍
        executor.setQueueCapacity(availableProcessors * 4);

        executor.setThreadNamePrefix("StudentPaperTaskExecutor-");
        executor.setRejectedExecutionHandler(new ThreadPoolExecutor.CallerRunsPolicy()); // 拒绝策略
        executor.setKeepAliveSeconds(60); // 线程空闲时间
        executor.setAllowCoreThreadTimeOut(true); // 允许核心线程超时
        executor.initialize();
        return executor;
    }
}


